/******************************************************************************
File:    SC_IPDEF.H
Project: Serial controller developers library
Purpose: Tunable interprocessor parameters.
Company: Comtrol Corporation
Author:  Craig Harrison
*******************************************************************************
Copyright 1993 Comtrol Corporation. All rights reserved.
Subject to developers license agreement.
*******************************************************************************
Comments:   This file contains defines that affect both the SCK and the SSCI.
            These can be changed by the developer to allow configuration of
            the SSCI and the SCK.
******************************************************************************/



/******************************************************************************
           Communications Parameter Flags for Baud Rates (UBYTE_T)
These flags are used to represent baud rates.  The baud rate generator
time constant can be obtained from these flags by calling kGetBaudTC().
Note:  The remainder of the communications parameter flags are in SC_IP.H.

                    Changing Baud Rate Generator Time Constants
Changing the COM_BAUD_XXX defines is normally not required.
These defines are used to convert a baud rate expressed in BPS into the baud
rate generator time constant used by the serial channel.  Each supported baud
rate has a define of the form COM_BAUD_XXX, where XXX is the baud rate.
COM_BAUD_XXX is used as an index into kBaudTCTbl[BAUDTCTBL_SIZE], which
contains the time constants.  The time constant entries in kBaudTCTbl also have
defines of the form BRTCYY, where YY is the index in kBaudTCTbl[] at which
that time constant is stored.  BRTCYY defines are located in C_KERNDF.H.
The developer can modify the COM_BAUD_XXX and BRTCYY defines.
This would be done if new baud rates at added, if the channel clock multiplier
is changed, or if the channel clock frequency is changed in hardware.
******************************************************************************/
#define COM_BAUD_50    0
#define COM_BAUD_75    0x1
#define COM_BAUD_110   0x2
#define COM_BAUD_134   0x3
#define COM_BAUD_150   0x4
#define COM_BAUD_300   0x5
#define COM_BAUD_600   0x6
#define COM_BAUD_1200  0x7
#define COM_BAUD_1800  0x8
#define COM_BAUD_2000  0x9
#define COM_BAUD_2400  0xa
#define COM_BAUD_3600  0xb
#define COM_BAUD_4800  0xc
#define COM_BAUD_7200  0xd
#define COM_BAUD_9600  0xe
#define COM_BAUD_19200 0xf
#define COM_BAUD_38400 0x10
#define COM_BAUD_56000 0x11
#define COM_BAUD_76800 0x12



/******************************************************************************
                                SDB Size
This is the size of an SDB's data buffer, it must be in the range from 16
to 16384, and must be a multiple of 16.
******************************************************************************/
#define SDB_SIZE 128

